==> odoo_18.0.20251208.zip: odoo-18.0.post20251208/odoo/addons/pos_self_order/static/src/app/models/pos_order_line.js <==
/** @odoo-module */

import { PosOrderline } from "@point_of_sale/app/models/pos_order_line";
import { patch } from "@web/core/utils/patch";

patch(PosOrderline.prototype, {
    get changes() {
        const change = this.order_id.uiState.lineChanges[this.uuid];

        if (!change) {
            return {
                qty: this.qty,
                customer_note: this.customer_note,
                attribute_value_ids: JSON.stringify(
                    this.attribute_value_ids.map((a) => a.id).sort()
                ),
                custom_attribute_value_ids: JSON.stringify(
                    this.custom_attribute_value_ids.map((a) => a.id).sort()
                ),
            };
        }

        const diff = {
            qty: this.qty !== change.qty ? this.qty - change.qty : false,
            customer_note:
                this.customer_note !== change.customer_note ? change.customer_note : false,
            attribute_value_ids:
                JSON.stringify(this.attribute_value_ids.map((a) => a.id).sort()) !==
                change.attribute_value_ids
                    ? change.attribute_value_ids
                    : false,
            custom_attribute_value_ids:
                JSON.stringify(this.custom_attribute_value_ids.map((a) => a.id).sort()) !==
                change.custom_attribute_value_ids
                    ? change.custom_attribute_value_ids
                    : false,
        };
        return diff;
    },
    isLotTracked() {
        return false;
    },
});

==> odoo_18.0.20260209.zip: odoo-18.0.post20260209/odoo/addons/pos_self_order/static/src/app/models/pos_order_line.js <==
/** @odoo-module */

import { PosOrderline } from "@point_of_sale/app/models/pos_order_line";
import { patch } from "@web/core/utils/patch";

patch(PosOrderline.prototype, {
    get changes() {
        const change = this.order_id.uiState.lineChanges[this.uuid];

        if (!change) {
            return {
                qty: this.qty,
                customer_note: this.customer_note,
                attribute_value_ids: JSON.stringify(
                    this.attribute_value_ids.map((a) => a.id).sort()
                ),
                custom_attribute_value_ids: JSON.stringify(
                    this.custom_attribute_value_ids.map((a) => a.id).sort()
                ),
            };
        }

        const diff = {
            qty: this.qty !== change.qty ? this.qty - change.qty : false,
            customer_note:
                this.customer_note !== change.customer_note ? change.customer_note : false,
            attribute_value_ids:
                JSON.stringify(this.attribute_value_ids.map((a) => a.id).sort()) !==
                change.attribute_value_ids
                    ? change.attribute_value_ids
                    : false,
            custom_attribute_value_ids:
                JSON.stringify(this.custom_attribute_value_ids.map((a) => a.id).sort()) !==
                change.custom_attribute_value_ids
                    ? change.custom_attribute_value_ids
                    : false,
        };
        return diff;
    },
    isLotTracked() {
        return false;
    },
    getDisplayPriceWithQty(qty) {
        const prices = this.get_all_prices(qty);

        if (this.config.iface_tax_included === "total") {
            return prices.priceWithTax;
        } else {
            return prices.priceWithoutTax;
        }
    },
});
